﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Windows.Forms;
using System.Drawing;


namespace VstupniTest
{
    public class Control
    {
        private Window window;
        private Point position;
        private int drawCount;
        private int moveCount;


        private Control() { }

        /// <summary>
        /// Objekt pro ovladani.
        /// </summary>
        /// <param name="x">Startovni pozice na ose X.</param>
        /// <param name="y">Startovni pozice na ose Y.</param>
        public Control(int x, int y)
        {
            Application.EnableVisualStyles();
            Application.SetCompatibleTextRenderingDefault(false);

            this.window = new Window(this);
            this.position = new Point(x, y);

            this.drawCount = 0;
            this.moveCount = 0;
        }


        /// <summary>
        /// Posune se do zadane pozice.
        /// </summary>
        /// <param name="x">Souradnice X.</param>
        /// <param name="y">Souradnice Y.</param>
        /// <returns>Pocet presunu.</returns>
        public int Move(int x, int y)
        {
            this.position = new Point(x, -y);

            this.window.SetMoveCount(++this.moveCount);
            return this.moveCount;
        }


        /// <summary>
        /// Vykresli usecku z aktualni pozice do nove pozice.
        /// </summary>
        /// <param name="x">Souradnice X.</param>
        /// <param name="y">Souradnice Y.</param>
        /// <param name="width">Tloustka usecky.</param>
        /// <param name="color">Barva usecky.</param>
        /// <returns>Pocet vykreslenych usecek.</returns>
        public int Draw(int x, int y, int width = 1, Color? color = null)
        {
            this.window.AddLine(new Line(this.position, new Point(x, -y), width, color));
            this.position = new Point(x, -y);

            this.window.SetDrawCount(++this.drawCount);
            return this.drawCount;
        }


        /// <summary>
        /// Dalsi hodnota N.
        /// </summary>
        public void Next()
        {
            Program.Next();
        }



        /// <summary>
        /// Zobrazeni GUI.
        /// </summary>
        public void Show()
        {
            Application.Run(this.window);
        }


        /// <summary>
        /// Prekresleni okna.
        /// </summary>
        public void Refresh()
        {
            this.window.Refresh();
        }


        /// <summary>
        /// Vycisti okno pro nove malovani
        /// </summary>
        /// <param name="x">Startovni pozice na ose X.</param>
        /// <param name="y">Startovni pozice na ose Y.</param>
        public void Reset(int x, int y)
        {
            this.position = new Point(x, y);

            this.drawCount = 0;
            this.moveCount = 0;
            this.window.SetDrawCount(0);
            this.window.SetMoveCount(0);

            this.window.Reset();
        }
    }
}
